@@ -31,6 +31,8 @@ class RelationalSchema:
         i = 0
         while len(self._docs_list) > 0:
             name, docs, foreign_keys = self._docs_list.pop()
+            while name in self.tables.keys():
+                name += "_"
             tab = Tabulator(deepcopy(docs), name, copy(foreign_keys))
             data, more_docs = tab.tabulate()
             new_table = Table(data, tab.primary_key, tab.foreign_keys)
